# Media Remote Social

A simple module that extends oEmbed support added to Drupal Core's Media module
by implementing hook_media_source_info_alter() for Meta platforms:
- Facebook
- Instagram


## Requirements

- Drupal Core Media (media) module.
- Key (key) module for secure storage of access tokens.


## Installation

`composer require drupal/media_remote_social:^1.0`


## Configuration

### Meta (Facebook & Instagram) Authentication

Facebook and Instagram require authentication for their oEmbed APIs. Both platforms use the same Meta access token. To configure:

1. **Create a Meta App:**
   - Go to [Meta for Developers](https://developers.facebook.com/)
   - Create a new app or use an existing one
   - Add the "Meta oEmbed Read" permission for Facebook and Instagram embedding
   - Navigate to Settings > Basic to find your App ID and App Secret

2. **Generate an Access Token:**
   - Use the Graph API Explorer, or
   - Create a token by combining: `APP_ID|APP_SECRET`
   - Note: For production use, your app must be reviewed and approved by Meta

3. **Store the Access Token in Drupal:**
   - Install and enable the Key module if not already done
   - Go to `/admin/config/system/keys/add` to create a new key
   - Set the key type to "Authentication" or "Generic"
   - Enter your Meta access token as the key value

4. **Configure Media Remote Social:**
   - Go to `/admin/config/media-remote-social`
   - Select the key containing your Meta access token
   - Save the configuration

The module will automatically append the access token to all Facebook and Instagram oEmbed requests.


## Features

- **Media type:** Creates a 'Remote social' Media type
- **Manage fields:** Creates a 'Social URL' (field_media_oembed_social) plain
  text field
- **Manage form display:** Uses the 'oEmbed URL' widget
- **Manage display:** Uses the 'oEmbed content' widget
- **Authentication:** Requires Meta access token for both Facebook and Instagram


## Usage:

To add Remote social content, simply go to `/media/add/remote_social`
and paste the social url from Facebook or Instagram.


## Why Only Facebook and Instagram?

This module focuses exclusively on Meta platforms (Facebook and Instagram) because:

1. **Shared Authentication:** Both platforms use the same Meta access token
2. **Reliable oEmbed:** Both provide consistent metadata and thumbnails
3. **API Stability:** Meta's Graph API provides stable, well-documented endpoints

Other social platforms were excluded due to:
- **X (Twitter):** No thumbnails, no structured metadata, poor oEmbed implementation
- **TikTok:** Security conflicts with Drupal's iframe isolation, unreliable JavaScript execution
- **Pinterest:** Inconsistent oEmbed support across different content types

For sites requiring other social platforms, consider using platform-specific modules or Drupal's core oEmbed support.


## Facebook & Instagram:

See: https://developers.facebook.com/docs/features-reference/oembed-read
- oEmbed Page: https://developers.facebook.com/docs/graph-api/reference/oembed-page/
- oEmbed Post: https://developers.facebook.com/docs/graph-api/reference/oembed-post/
- oEmbed Video: https://developers.facebook.com/docs/graph-api/reference/oembed-video/
- Instagram oEmbed: https://developers.facebook.com/docs/graph-api/reference/instagram-oembed/