# Data Deletion Instructions for Media Remote Social

**Last Updated: January 27, 2025**

## Overview

Media Remote Social does not collect, store, or process any personal user data. However, if you need to remove any data related to the Module, follow these instructions.

## What Data Can Be Deleted

1. **Meta Access Tokens**: Stored in your Drupal site for API authentication
2. **Cached Embed Data**: Temporarily stored oEmbed responses
3. **Media Entities**: Facebook and Instagram posts saved as media entities

## How to Delete Data

### 1. Delete Meta Access Tokens

To remove stored access tokens:

1. Navigate to `/admin/config/system/keys` in your Drupal site
2. Find the key containing your Meta access token
3. Click "Delete" next to the key
4. Confirm deletion

### 2. Clear Cached Embed Data

To remove cached oEmbed data:

```bash
# Using Drush
drush cr

# Or via UI
# Navigate to /admin/config/development/performance
# Click "Clear all caches"
```

### 3. Delete Media Entities

To remove Facebook/Instagram media entities:

1. Navigate to `/admin/content/media`
2. Filter by "Remote social" media type
3. Select the media items to delete
4. Choose "Delete media" from the actions dropdown
5. Confirm deletion

### 4. Complete Module Removal

To completely remove the Module and all associated data:

```bash
# Uninstall the module
drush pm:uninstall media_remote_social

# Remove the module files
composer remove drupal/media_remote_social
```

## Automated Data Deletion

The Module does not retain any user data that requires automated deletion. All data is either:
- Configuration data controlled by site administrators
- Publicly available content from Meta's APIs
- Temporary cache data that expires automatically

## No Personal Data Collection

**Important**: Media Remote Social does not:
- Collect personal information from end users
- Store user profiles or preferences  
- Track user behavior or analytics
- Create user accounts
- Use cookies or local storage

Therefore, there is no personal user data to delete.

## Data Deletion Requests

Since the Module does not collect personal data, data deletion requests should be directed to:
- **Your website administrator**: For removing embedded content
- **Meta/Facebook**: For deletion of the original social media posts

## Contact Information

For questions about data deletion, please contact your website administrator or visit:
https://github.com/drupal/media_remote_social

## Note for Website Administrators

When uninstalling the Module:
1. All Remote social media entities will remain in your database
2. You should manually delete these if complete removal is desired
3. Access tokens stored via Key module must be deleted separately
4. Clear all caches after module removal