<?php

namespace Drupal\media_remote_social\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\key\KeyRepositoryInterface;
use Drupal\media\OEmbed\UrlResolverEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Alters oEmbed URLs to add authentication tokens.
 */
class OembedUrlAlterSubscriber implements EventSubscriberInterface {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The key repository.
   *
   * @var \Drupal\key\KeyRepositoryInterface
   */
  protected $keyRepository;

  /**
   * Constructs an OembedUrlAlterSubscriber object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\key\KeyRepositoryInterface $key_repository
   *   The key repository.
   */
  public function __construct(ConfigFactoryInterface $config_factory, KeyRepositoryInterface $key_repository) {
    $this->configFactory = $config_factory;
    $this->keyRepository = $key_repository;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      UrlResolverEvent::class => 'onUrlResolve',
    ];
  }

  /**
   * Alters the oEmbed URL to add authentication tokens.
   *
   * @param \Drupal\media\OEmbed\UrlResolverEvent $event
   *   The URL resolver event.
   */
  public function onUrlResolve(UrlResolverEvent $event) {
    $url = $event->getUrl();
    
    // Check if this is a Facebook oEmbed URL.
    if (strpos($url, 'graph.facebook.com') !== FALSE) {
      $config = $this->configFactory->get('media_remote_social.settings');
      $key_id = $config->get('facebook_access_token_key');
      
      if ($key_id) {
        $key = $this->keyRepository->getKey($key_id);
        if ($key) {
          $access_token = $key->getKeyValue();
          if ($access_token) {
            // Add access token to the URL.
            $separator = strpos($url, '?') !== FALSE ? '&' : '?';
            $event->setUrl($url . $separator . 'access_token=' . urlencode($access_token));
          }
        }
      }
    }
  }

}